<!-- 新增政策 -->
<template>
  <el-dialog title="惠企政策" v-model="dialogVisible" width="900px" append-to-body @close="closeDialog">
    <div style="padding: 0 20px;">
      <el-form :model="form" :rules="rules" ref="form" label-width="80px">
        <el-form-item label="政策类型" prop="docType">
          <el-select v-model="form.docType" placeholder="请选择" style="width: 200px">
            <el-option v-for="(item, index) in policyList" :label="item.label" :value="item.value"></el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="政策名称" prop="docTitle">
          <el-input v-model="form.docTitle" placeholder="请输入政策名称"></el-input>
        </el-form-item>
        <el-form-item label="政策内容" prop="docContent">
          <div>
            <editPolicy v-model="form.docContent"></editPolicy>
          </div>
        </el-form-item>
        <el-form-item label="状态">
          <el-switch v-model="form.docStatus" :active-value="0" :inactive-value="1"></el-switch>
        </el-form-item>
      </el-form>
    </div>
    <template v-slot:footer>
      <el-button type="primary" @click="addDocHandler">确认</el-button>
      <el-button @click="closeDialog">取消</el-button>
    </template>
  </el-dialog>
</template>

<script>
import editPolicy from '@/components/Editor/index'
import { addDoc, updDoc } from '@/api/system/company/company'
export default {
  components: {
    editPolicy
  },
  props: {
    policyList: {
      type: Array,
      default: () => {
        return []
      }
    }
  },
  data() {
    return {
      dialogVisible: false,
      form: {
        docStatus: 0
      },
      rules: {
        docType: [{
          required: true,
          message: '请输入政策名称',
          trigger: 'blur'
        }],
        docTitle: [
          {
            required: true,
            message: '请输入政策名称',
            trigger: 'blur'
          }
        ],
        docName: [
          {
            required: true,
            message: '请输入政策名称',
            trigger: 'blur'
          }
        ],
        docContent: [
          {
            required: true,
            message: '请输入政策内容',
            trigger: 'blur'
          }
        ]
      }
    }
  },
  methods: {
    closeDialog() {
      this.dialogVisible = false
      this.$emit('upload')
    },
    openDialog(row) {
      if (row) {
        row.docType = Number(row.docType) 
        this.form = row
        this.form.docContent = decodeURIComponent(row.docContent)
      } else {
        this.form = {
          docStatus: 0
        }
      }
      this.dialogVisible = true
    },
    addDocHandler() {
      this.$refs.form.validate((valid) => {
        if (valid) {
          const form = JSON.parse(JSON.stringify(this.form))
          form.docContent = encodeURIComponent(this.form.docContent)
          if (form.docId) {
            updDoc(form).then(val => {
              this.$message.success('添加成功')
              this.closeDialog()
              this.$emit('upload')
            }).catch(err => {
              console.log(err)
            })
          } else {
            addDoc(form).then(val => {
              this.$message.success('添加成功')
              this.closeDialog()
              this.$emit('upload')
            }).catch(err => {
              console.log(err.message)
            })
          }
        }
      })

    }
  }
}
</script>